# NoneBot-Plugin-jingdong
基于NoneBot2的京东查询插件。  
第一次写插件，~~可能~~ 肯定有许许多多的问题。

### 安装说明
```
环境：
httpx、random、bs4、nonebot、typing

下载：  
直接下载插件文件夹塞入Bot的插件文件夹
```

### 使用说明
```
京东搜索：
    jdss/京东搜索 商品名称
    （如：京东搜索 内存）
    
    搜索结果为30条数据！
    群聊：消息转发类型,附带商品图片。
    频道：长文本！无图片！
    私聊：由于信息较长，已删除在私聊中的该功能。

京东详情：
    jdxq/京东详情 商品编号
    （如：京东详情 100011848197）
    
    搜索结果为图片+描述。
    群私频都可以使用。
```

### 其他  
原本是想要个降价通知的，但发现插件商店没有类似插件。  
于是动手写并最终写跑题成了查询插件。（其实是太菜了，写不出来）  
